Struct tlb_ton::InternalMsgInfo
source · pub struct InternalMsgInfo {
pub ihr_disabled: bool,
pub bounce: bool,
pub bounced: bool,
pub src: MsgAddress,
pub dst: MsgAddress,
pub value: CurrencyCollection,
pub ihr_fee: BigUint,
pub fwd_fee: BigUint,
pub created_lt: u64,
pub created_at: DateTime<Utc>,
}Expand description
int_msg_info$0 ihr_disabled:Bool bounce:Bool bounced:Bool src:MsgAddressInt dest:MsgAddressInt value:CurrencyCollection ihr_fee:Grams fwd_fee:Grams created_lt:uint64 created_at:uint32 = CommonMsgInfo;
Fields
ihr_disabled: boolHyper cube routing flag.
bounce: boolMessage should be bounced if there are errors during processing. If message’s flat bounce = 1, it calls bounceable.
bounced: boolFlag that describes, that message itself is a result of bounce.
src: MsgAddressAddress of smart contract sender of message.
dst: MsgAddressAddress of smart contract destination of message.
value: CurrencyCollectionStructure which describes currency information including total funds transferred in message.
ihr_fee: BigUintFees for hyper routing delivery
fwd_fee: BigUintFees for forwarding messages assigned by validators
created_lt: u64Logic time of sending message assigned by validator. Using for odering actions in smart contract.
created_at: DateTime<Utc>Unix time